=========
Community
=========

We value comments, questions, feature requests, and any other feedback from our
community. Thank you for using Coiled! You rock 🤘


Discussion
----------

We have a public
`Coiled community Slack <https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ>`_
for chatting about Coiled and Dask, asking questions, and sharing tips.
Both Coiled users and Coiled engineers engage on Slack, so it's a good place to
get help!

.. link-button:: https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ
    :type: url
    :text: Join the Coiled community Slack 🎉
    :classes: btn-outline-primary btn-block

Feedback
--------

Feedback on Coiled is always welcome and encouraged. In particular, if you
have a feature request or have encountered a bug please
`open an issue <https://github.com/coiled/feedback/issues/new>`_ in the
Coiled issue tracker on GitHub.

.. link-button:: https://github.com/coiled/feedback/issues/new
    :type: url
    :text: Report a bug or feature request
    :classes: btn-outline-primary btn-block